@@ -1,10 +1,12 @@
-from pyvalid.__accepts import accepts
-from pyvalid.__returns import returns
+from pyvalid.__accepts import Accepts
+from pyvalid.__returns import Returns
 from pyvalid.__exceptions import InvalidArgumentNumberError, \
     InvalidReturnType, ArgumentValidationError
 
 
-version = '0.2'
+accepts = Accepts
+returns = Returns
+version = '0.3'
 
 
 __all__ = [
