@@ -2,7 +2,7 @@ from collections import Callable
 from pyvalid.__exceptions import InvalidReturnType
 
 
-class returns(Callable):
+class Returns(Callable):
     """A decorator to validate the returns value of a given function.
     """
 
@@ -26,4 +26,4 @@ class returns(Callable):
                 if not is_valid:
                     raise InvalidReturnType(type(returns_value), func.__name__)
             return returns_value
-        return decorator_wrapper
\ No newline at end of file
+        return decorator_wrapper
